==> servicecatalogappregistry-alpha-2.65.0-alpha.0-sources.jar: software/amazon/awscdk/services/servicecatalogappregistry/alpha/TargetApplication.java <==
package software.amazon.awscdk.services.servicecatalogappregistry.alpha;

/**
 * (experimental) Contains static factory methods with which you can build the input needed for application associator to work.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * App app = new App();
 * ApplicationAssociator associatedApp = ApplicationAssociator.Builder.create(app, "AssociatedApplication")
 *         .applications(List.of(TargetApplication.createApplicationStack(CreateTargetApplicationOptions.builder()
 *                 .applicationName("MyAssociatedApplication")
 *                 // 'Application containing stacks deployed via CDK.' is the default
 *                 .applicationDescription("Associated Application description")
 *                 .stackName("MyAssociatedApplicationStack")
 *                 // AWS Account and Region that are implied by the current CLI configuration is the default
 *                 .env(Environment.builder().account("123456789012").region("us-east-1").build())
 *                 .build())))
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.74.0 (build 6d08790)", date = "2023-02-15T19:53:17.866Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.servicecatalogappregistry.alpha.$Module.class, fqn = "@aws-cdk/aws-servicecatalogappregistry-alpha.TargetApplication")
public abstract class TargetApplication extends software.amazon.jsii.JsiiObject {

    protected TargetApplication(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected TargetApplication(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    protected TargetApplication() {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this);
    }

    /**
     * (experimental) Factory method to build the input using the provided application name and stack props.
     * <p>
     * @param options This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.servicecatalogappregistry.alpha.TargetApplication createApplicationStack(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.servicecatalogappregistry.alpha.CreateTargetApplicationOptions options) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.servicecatalogappregistry.alpha.TargetApplication.class, "createApplicationStack", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.servicecatalogappregistry.alpha.TargetApplication.class), new Object[] { java.util.Objects.requireNonNull(options, "options is required") });
    }

    /**
     * (experimental) Factory method to build the input using the provided application ARN.
     * <p>
     * @param options This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.servicecatalogappregistry.alpha.TargetApplication existingApplicationFromArn(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.servicecatalogappregistry.alpha.ExistingTargetApplicationOptions options) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.servicecatalogappregistry.alpha.TargetApplication.class, "existingApplicationFromArn", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.servicecatalogappregistry.alpha.TargetApplication.class), new Object[] { java.util.Objects.requireNonNull(options, "options is required") });
    }

    /**
     * (experimental) Called when the ApplicationAssociator is initialized.
     * <p>
     * @param scope This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public abstract @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.servicecatalogappregistry.alpha.BindTargetApplicationResult bind(final @org.jetbrains.annotations.NotNull software.constructs.Construct scope);

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    @software.amazon.jsii.Internal
    private static final class Jsii$Proxy extends software.amazon.awscdk.services.servicecatalogappregistry.alpha.TargetApplication {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
        }

        /**
         * (experimental) Called when the ApplicationAssociator is initialized.
         * <p>
         * @param scope This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.servicecatalogappregistry.alpha.BindTargetApplicationResult bind(final @org.jetbrains.annotations.NotNull software.constructs.Construct scope) {
            return software.amazon.jsii.Kernel.call(this, "bind", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.servicecatalogappregistry.alpha.BindTargetApplicationResult.class), new Object[] { java.util.Objects.requireNonNull(scope, "scope is required") });
        }
    }
}

==> servicecatalogappregistry-alpha-2.71.0-alpha.0-sources.jar: software/amazon/awscdk/services/servicecatalogappregistry/alpha/TargetApplication.java <==
package software.amazon.awscdk.services.servicecatalogappregistry.alpha;

/**
 * (experimental) Contains static factory methods with which you can build the input needed for application associator to work.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * import software.amazon.awscdk.*;
 * App app = new App();
 * ApplicationAssociator associatedApp = ApplicationAssociator.Builder.create(app, "AssociatedApplication")
 *         .applications(List.of(TargetApplication.createApplicationStack(CreateTargetApplicationOptions.builder()
 *                 .applicationName("MyAssociatedApplication")
 *                 // 'Application containing stacks deployed via CDK.' is the default
 *                 .applicationDescription("Associated Application description")
 *                 .stackName("MyAssociatedApplicationStack")
 *                 // AWS Account and Region that are implied by the current CLI configuration is the default
 *                 .env(Environment.builder().account("123456789012").region("us-east-1").build())
 *                 .build())))
 *         .build();
 * // Associate application to the attribute group.
 * associatedApp.appRegistryApplication.addAttributeGroup("MyAttributeGroup", AttributeGroupAssociationProps.builder()
 *         .attributeGroupName("MyAttributeGroupName")
 *         .description("Test attribute group")
 *         .attributes(Map.of())
 *         .build());
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.77.0 (build 3e5fa88)", date = "2023-03-29T12:50:55.005Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.servicecatalogappregistry.alpha.$Module.class, fqn = "@aws-cdk/aws-servicecatalogappregistry-alpha.TargetApplication")
public abstract class TargetApplication extends software.amazon.jsii.JsiiObject {

    protected TargetApplication(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected TargetApplication(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    protected TargetApplication() {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this);
    }

    /**
     * (experimental) Factory method to build the input using the provided application name and stack props.
     * <p>
     * @param options This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.servicecatalogappregistry.alpha.TargetApplication createApplicationStack(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.servicecatalogappregistry.alpha.CreateTargetApplicationOptions options) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.servicecatalogappregistry.alpha.TargetApplication.class, "createApplicationStack", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.servicecatalogappregistry.alpha.TargetApplication.class), new Object[] { java.util.Objects.requireNonNull(options, "options is required") });
    }

    /**
     * (experimental) Factory method to build the input using the provided application ARN.
     * <p>
     * @param options This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.servicecatalogappregistry.alpha.TargetApplication existingApplicationFromArn(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.servicecatalogappregistry.alpha.ExistingTargetApplicationOptions options) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.servicecatalogappregistry.alpha.TargetApplication.class, "existingApplicationFromArn", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.servicecatalogappregistry.alpha.TargetApplication.class), new Object[] { java.util.Objects.requireNonNull(options, "options is required") });
    }

    /**
     * (experimental) Called when the ApplicationAssociator is initialized.
     * <p>
     * @param scope This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public abstract @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.servicecatalogappregistry.alpha.BindTargetApplicationResult bind(final @org.jetbrains.annotations.NotNull software.constructs.Construct scope);

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    @software.amazon.jsii.Internal
    private static final class Jsii$Proxy extends software.amazon.awscdk.services.servicecatalogappregistry.alpha.TargetApplication {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
        }

        /**
         * (experimental) Called when the ApplicationAssociator is initialized.
         * <p>
         * @param scope This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.servicecatalogappregistry.alpha.BindTargetApplicationResult bind(final @org.jetbrains.annotations.NotNull software.constructs.Construct scope) {
            return software.amazon.jsii.Kernel.call(this, "bind", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.servicecatalogappregistry.alpha.BindTargetApplicationResult.class), new Object[] { java.util.Objects.requireNonNull(scope, "scope is required") });
        }
    }
}
